# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Shenzhen dataset for computer-aided diagnosis.

The standard digital image database for Tuberculosis is created by the
National Library of Medicine, Maryland, USA in collaboration with Shenzhen
No.3 People’s Hospital, Guangdong Medical College, Shenzhen, China.
The Chest X-rays are from out-patient clinics, and were captured as part of
the daily routine using Philips DR Digital Diagnose systems.

* Reference: [MONTGOMERY-SHENZHEN-2014]_
* Original resolution (height x width or width x height): 3000 x 3000 or less
* Split reference: none
  * Training samples: 64% of TB and healthy CXR (including labels)
  * Validation samples: 16% of TB and healthy CXR (including labels)
  * Test samples: 20% of TB and healthy CXR (including labels)
"""
import importlib.resources

_protocols = [
    importlib.resources.files(__name__).joinpath("default.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_0.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_1.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_2.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_3.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_4.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_5.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_6.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_7.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_8.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_9.json.bz2"),
]
