# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Shenzhen datamodule for computer-aided diagnosis (default protocol)

See :py:mod:`ptbench.data.shenzhen` for more database details.

This configuration:

* Raw data input (on disk):

  * PNG images (black and white, encoded as color images)
  * Variable width and height:

    * widths: from 1130 to 3001 pixels
    * heights: from 948 to 3001 pixels

* Output image:

  * Transforms:

    * Load raw PNG with :py:mod:`PIL`
    * Remove black borders
    * Torch resizing(512px, 512px)
    * Torch center cropping (512px, 512px)

  * Final specifications:

    * Fixed resolution: 512x512 pixels
    * Color RGB encoding
"""

import importlib.resources

from ..datamodule import CachingDataModule
from ..split import JSONDatabaseSplit
from .loader import RawDataLoader

datamodule = CachingDataModule(
    database_split=JSONDatabaseSplit(
        importlib.resources.files(__name__.rsplit(".", 1)[0]).joinpath(
            "default.json.bz2"
        )
    ),
    raw_data_loader=RawDataLoader(),
)
