# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Shenzhen datamodule for computer-aided diagnosis (default protocol)

See :py:mod:`ptbench.data.shenzhen` for dataset details.

This configuration:
* raw data (default): :py:obj:`ptbench.data.shenzhen._tranforms`
* augmentations: elastic deformation (probability = 80%)
* output image resolution: 512x512 pixels
"""

import importlib.resources

from torchvision import transforms

from ..datamodule import CachingDataModule
from ..split import JSONDatabaseSplit
from .raw_data_loader import raw_data_loader

datamodule = CachingDataModule(
    database_split=JSONDatabaseSplit(
        importlib.resources.files(__name__.rsplit(".", 1)[0]).joinpath(
            "default.json.bz2"
        )
    ),
    raw_data_loader=raw_data_loader,
    cache_samples=False,
    # train_sampler: typing.Optional[torch.utils.data.Sampler] = None,
    model_transforms=[
        transforms.ToPILImage(),
        transforms.Lambda(lambda x: x.convert("RGB")),
        transforms.ToTensor(),
    ],
    # batch_size = 1,
    # batch_chunk_count = 1,
    # drop_incomplete_batch = False,
    # parallel = -1,
)
